==> srb-0.0.3.tar.gz: srb-0.0.3/docs/src/envs/manipulation.md <==
# Environments — Manipulation (Static)

The Space Robotics Bench provides a wide range of environments that focus on stationary manipulation across different application domains of space robotics.

### Sample Collection (`sample_collection`)

> Grasping and collection of samples on planetary surfaces

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/1NYquT2EZdo?si=gkt2wM0VfnaFs797&mute=1&autoplay=1&loop=1&playlist=1NYquT2EZdo" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

#### Sample Collection — Multi (`sample_collection_multi`)

> A variation of sample collection with multiple samples

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/CyPJr6LSUac?si=9gmKE_dIDPhwDgYE&mute=1&autoplay=1&loop=1&playlist=CyPJr6LSUac" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Debris Capture (`debris_capture`)

> Capture and securement of floating debris in microgravity with a fixed-base manipulator

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/3zog4qGHg6A?si=ImyO-2F0nZqEYNjh&mute=1&autoplay=1&loop=1&playlist=3zog4qGHg6A" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Peg-in-Hole Assembly (`peg_in_hole_assembly`)

> Precision assembly task requiring the robot to insert a peg into a hole

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/C8xhE6hHG9I?si=5_fy6yqut35iPD9B&mute=1&autoplay=1&loop=1&playlist=C8xhE6hHG9I" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/2ChSPhO9Y5s?si=JxX52BuI9K-W_8eb&mute=1&autoplay=1&loop=1&playlist=2ChSPhO9Y5s" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

#### Peg-in-Hole Assembly — Multi (`peg_in_hole_assembly_multi`)

> A variation of peg-in-hole assembly with multiple pegs and holes

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/50nKU-myKbM?si=Gvh9TxN8F8KCot1o&mute=1&autoplay=1&loop=1&playlist=50nKU-myKbM" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Solar Panel Assembly (`solar_panel_assembly`)

> Complex assembly sequence involving solar panel components

<img src="https://github.com/user-attachments/assets/34466dbb-0520-4899-ad14-862326961d8a" style="width:50%" /><img src="https://github.com/user-attachments/assets/b73113de-c37d-4d26-9599-ebe52cbc605b" style="width:50%" />

==> srb-0.0.4.tar.gz: srb-0.0.4/docs/src/envs/manipulation.md <==
# Environments — Manipulation (Static)

The Space Robotics Bench provides a wide range of environments that focus on stationary manipulation across different application domains of space robotics.

### Sample Collection (`sample_collection`)

> Grasping and collection of samples on planetary surfaces

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/1NYquT2EZdo?si=gkt2wM0VfnaFs797&mute=1&autoplay=1&loop=1&playlist=1NYquT2EZdo" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

#### Sample Collection — Multi (`multi_sample_collection`)

> A variation of sample collection with multiple samples

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/CyPJr6LSUac?si=9gmKE_dIDPhwDgYE&mute=1&autoplay=1&loop=1&playlist=CyPJr6LSUac" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Excavation (`excavation`)

> Extraction of granular material (regolith)

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/XIJhFsaT1Ls?si=_0waG1xvKRnu2VNs&mute=1&autoplay=1&loop=1&playlist=XIJhFsaT1Ls" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Debris Capture (`debris_capture`)

> Capture and securement of floating debris in microgravity with a fixed-base manipulator

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/3zog4qGHg6A?si=ImyO-2F0nZqEYNjh&mute=1&autoplay=1&loop=1&playlist=3zog4qGHg6A" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Peg-in-Hole Assembly (`peg_in_hole_assembly`)

> Precision assembly task requiring the robot to insert a peg into a hole

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/C8xhE6hHG9I?si=5_fy6yqut35iPD9B&mute=1&autoplay=1&loop=1&playlist=C8xhE6hHG9I" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

#### Peg-in-Hole Assembly — Multi (`multi_peg_in_hole_assembly`)

> A variation of peg-in-hole assembly with multiple pegs and holes

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/50nKU-myKbM?si=Gvh9TxN8F8KCot1o&mute=1&autoplay=1&loop=1&playlist=50nKU-myKbM" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Screwdriving (`screwdriving`)

> Fastening of a pre-inserted bolt

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/w25DwrgeG2M?si=6NhaQBg9Rd6aFWRJ&mute=1&autoplay=1&loop=1&playlist=w25DwrgeG2M" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

### Solar Panel Assembly (`solar_panel_assembly`)

> Complex assembly sequence involving solar panel components

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/tY5XDuhdzOc?si=LrL0PEppQIA2ymTc&mute=1&autoplay=1&loop=1&playlist=tY5XDuhdzOc" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>
